@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "filtericedovetest.h"
 #include "filters/filtericedove.h"
 #include "filterimportertest.h"
-#include <qtest.h>
+#include <QTest>
 
 class FilterIcecoveAbstract : public MailImporter::FilterIcedove
 {
@@ -55,34 +55,37 @@ void FilterIcedoveTest::shouldImportData()
 void FilterIcedoveTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterIcedove filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QString());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 void FilterIcedoveTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterIcedove filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 void FilterIcedoveTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterIcedove filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 QTEST_MAIN(FilterIcedoveTest)
